@@ -6,7 +6,6 @@ import re
 
 from calendar import timegm
 from datetime import timedelta, MAXYEAR
-from time import time
 
 from dateutil import relativedelta
 from dateutil.tz import tzlocal, tzutc
@@ -40,7 +39,7 @@ class ParseError(ValueError):
 
 
 timedelta_pattern = r''
-for name, sym in [('years', 'y'), ('weeks', 'w'), ('days', 'd'),
+for name, sym in [('years', 'y'), ('months', 'M'), ('weeks', 'w'), ('days', 'd'),
                   ('hours', 'h'), ('minutes', 'm'), ('seconds', 's')]:
     timedelta_pattern += r'((?P<{0}>(?:\+|-)\d+?){1})?'.format(name, sym)
 
@@ -1474,7 +1473,7 @@ class Provider(BaseProvider):
     @classmethod
     def _parse_end_datetime(cls, value):
         if value is None:
-            return int(time())
+            return datetime_to_timestamp(datetime.now())
 
         return cls._parse_date_time(value)
 
@@ -1493,6 +1492,10 @@ class Provider(BaseProvider):
             if 'days' not in time_params:
                 time_params['days'] = 0
             time_params['days'] += 365.24 * time_params.pop('years')
+        if 'months' in time_params:
+            if 'days' not in time_params:
+                time_params['days'] = 0
+            time_params['days'] += 30.42 * time_params.pop('months')
 
         if not time_params:
             raise ParseError("Can't parse date string `{}`.".format(value))
